==> apache-camel-quarkus-3.15.4-src.zip: camel-quarkus-3.15.4/extensions/knative/runtime/src/main/java/org/apache/camel/quarkus/component/knative/KnativeProducerRecorder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.knative;

import java.util.function.Supplier;

import io.quarkus.runtime.RuntimeValue;
import io.quarkus.runtime.annotations.Recorder;
import io.vertx.core.Vertx;
import org.apache.camel.Component;
import org.apache.camel.component.knative.KnativeComponent;
import org.apache.camel.component.knative.http.KnativeHttpProducerFactory;
import org.apache.camel.spi.ComponentCustomizer;

@Recorder
public class KnativeProducerRecorder {
    public RuntimeValue<ComponentCustomizer> createKnativeProducerFactoryCustomizer(Supplier<Vertx> vertx) {
        KnativeHttpProducerFactory factory = new KnativeHttpProducerFactory();
        factory.setVertx(vertx.get());

        ComponentCustomizer cf = new ComponentCustomizer() {
            @Override
            public void configure(String name, Component target) {
                if (target instanceof KnativeComponent) {
                    ((KnativeComponent) target).setProducerFactory(factory);
                }
            }
        };

        return new RuntimeValue<>(cf);
    }
}

==> apache-camel-quarkus-3.20.3-src.zip: camel-quarkus-3.20.3/extensions/knative/runtime/src/main/java/org/apache/camel/quarkus/component/knative/KnativeProducerRecorder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.knative;

import java.util.function.Supplier;

import io.quarkus.runtime.RuntimeValue;
import io.quarkus.runtime.annotations.Recorder;
import io.vertx.core.Vertx;
import org.apache.camel.CamelContext;
import org.apache.camel.Component;
import org.apache.camel.component.knative.KnativeComponent;
import org.apache.camel.component.knative.http.KnativeHttpProducerFactory;
import org.apache.camel.spi.ComponentCustomizer;

@Recorder
public class KnativeProducerRecorder {
    public RuntimeValue<ComponentCustomizer> createKnativeProducerFactoryCustomizer(RuntimeValue<CamelContext> context,
            Supplier<Vertx> vertx) {
        KnativeHttpProducerFactory factory = new KnativeHttpProducerFactory();
        factory.setVertx(vertx.get());
        factory.setCamelContext(context.getValue());

        ComponentCustomizer cf = new ComponentCustomizer() {
            @Override
            public void configure(String name, Component target) {
                if (target instanceof KnativeComponent) {
                    ((KnativeComponent) target).setProducerFactory(factory);
                }
            }
        };

        return new RuntimeValue<>(cf);
    }
}
